@@ -7,24 +7,24 @@ cli::test_that_cli("key printing works", {
 
 testthat::test_that("Keys matched to Selenium keys", {
   expect_equal(
-    get_selenider_key(keys$backspace),
+    get_rselenium_key(keys$backspace),
     RSelenium::selKeys$backspace
   )
 
   expect_equal(
-    get_selenider_key(keys$f1),
+    get_rselenium_key(keys$f1),
     RSelenium::selKeys$f1
   )
 
   expect_equal(
-    get_selenider_key(keys$command),
+    get_rselenium_key(keys$command),
     RSelenium::selKeys$command_meta
   )
 })
 
 test_that("Each key has a selenium key definition", {
   for (key in keys) {
-    rlang::inject(expect_no_error(get_selenider_key(!!key)))
+    rlang::inject(expect_no_error(get_rselenium_key(!!key)))
   }
 })
 
